@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2013-2016 Horde LLC
+ * @copyright 2013-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Prefs
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013-2016 Horde LLC
+ * @copyright 2013-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Prefs
  */
@@ -83,8 +83,8 @@ implements Horde_Mongo_Collection_Index
                 self::SCOPE => $scope_ob->scope,
                 self::UID => $this->_params['user']
             ), array(
-                self::NAME => 1,
-                self::VALUE => 1
+                self::NAME => true,
+                self::VALUE => true
             ));
         } catch (MongoException $e) {
             throw new Horde_Prefs_Exception($e);
